/*
 * Project name:
     Master;
 * Copyright:
     (c) MikroElektronika, 2005-2011.
  * Revision History:
     20110426:
       - initial release (SZ);
 * Description:
     This is a simple project which demonstrates the use of the BlueTooth Stick2 module.
     After establishing the connection Master repeatedly sends two strings ("mikroE" and "BlueTooth Stick2")
     to the Slave. The Slave receives them and displays them at the 2x16 COG LCD.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/eng/products/view/321/easyavr6-development-system/
     Oscillator:      External, 8.0000 MHz
     Ext. Modules:    BlueTooth Stick2 at PORTD
                      ac:BlueTooth_Stick2_Board
                      http://www.mikroe.com/eng/products/view/680/bluetooth-2-stick/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
  - BlueTooth Stick2: Connect only Vcc, Gnd, Rx and Tx lines. You could use our Wire Jumpers:
    http://www.mikroe.com/eng/products/view/495/wire-jumpers/
    Also, 5V-3.3V Voltage Translator Board is required:
    http://www.mikroe.com/eng/products/view/182/5v-3-3v-voltage-translator-board/
  - Note that BlueGiga WT41 has default baudrate 115200bps and that you need to change the
    its firmware in order to run this example at 19200bps. Find out more here: http://www.bluegiga.com
  - Turn on both modules at the same time and wait for about one minute until the
    connection between the Master and the Slave establishes.
*/

void Wait(){
Delay_ms(1000);
}

void Wait2(){
char i;
for(i = 0; i < 30; i++) Delay_ms(1000);
}

void main() {

  UART1_Init(19200);                            // Initialize UART1 module
  Wait(); Wait(); Wait();

  UART1_Write_Text("SET RESET");                // The SET RESET command returns the factory settings of the module  
  UART1_Write(0x0D);                            // CR  
  Wait();
  
  UART1_Write_Text("SET BT PAIR *");            // If command SET BT PAIR * is given, all pairings will be removed                  
  UART1_Write(0x0D);                            // CR  
  Wait();
  
  UART1_Write_Text("RESET");                    // Command RESET is used to perform a software reset                  
  UART1_Write(0x0D);                            // CR  
  Wait();
 
// The CALL command is used to initiate Bluetooth connections to the remote devices
// Instead of xx:xx:xx:xx:xx:xx enter real MAC address of the BT module you want to call 
  UART1_Write_Text("CALL xx:xx:xx:xx:xx:xx 1 RFCOMM");  
  UART1_Write(0x0D);                            // CR  
  Wait2(); 


  while (1) {
    UART1_Write_Text("mikroE");                 // Sending Data to Slave module
    UART1_Write(13);                            // CR
    Wait();
    UART1_Write_Text("BlueTooth Stick2");       // Data
    UART1_Write(13);                            // CR
    Wait();
  }
}