/*
 * Project name:
     Slave;
 * Copyright:
     (c) MikroElektronika, 2005-2011.
  * Revision History:
     20110426:
       - initial release (SZ);
 * Description:
     This is a simple project which demonstrates the use of the BlueTooth Stick2 module.
     After establishing the connection Master repeatedly sends two strings ("mikroE" and "BlueTooth Stick2")
     to the Slave. The Slave receives them and displays them at the 2x16 COG LCD.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/eng/products/view/321/easyavr6-development-system/
     Oscillator:      External, 8.0000 MHz
     Ext. Modules:    BlueTooth Stick2 at PORTD
                      ac:BlueTooth_Stick2_Board
                      http://www.mikroe.com/eng/products/view/680/bluetooth-2-stick/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
  - BlueTooth Stick2: Connect only Vcc, Gnd, Rx and Tx lines. You could use our Wire Jumpers:
    http://www.mikroe.com/eng/products/view/495/wire-jumpers/
    Also, 5V-3.3V Voltage Translator Board is required:
    http://www.mikroe.com/eng/products/view/182/5v-3-3v-voltage-translator-board/
  - Note that BlueGiga WT41 has default baudrate 115200bps and that you need to change the
    its firmware in order to run this example at 19200bps. Find out more here: http://www.bluegiga.com
  - Turn on both modules at the same time and wait for about one minute until the
    connection between the Master and the Slave establishes.
  - Turn on switches SW6.1, SW6.5, SW6.7, SW7.1 and SW7.5.
  - Turn on COG LCD 2x16 switches SW10.1, SW10.2, SW10.3, SW10.4, SW10.5 and SW10.6.
*/


// Port Expander module connections
sbit  SPExpanderRST at PORTB2_bit;
sbit  SPExpanderCS  at PORTB1_bit;
sbit  SPExpanderRST_Direction at DDB2_bit;
sbit  SPExpanderCS_Direction  at DDB1_bit;
// End Port Expander module connections

char txt[17];
unsigned short i, tmp, DataReady;


// Uart Rx interrupt handler
void interrupt() org IVT_ADDR_USART_RXC {
    tmp = UART1_Read();                         // Get received byte

       if (tmp == 13) {
         txt[i] = 0;                            // Puting 0 at the end of the string
         DataReady = 1;                         // Data is received
       }
        else {
          txt[i] = tmp;                         // Moving the data received from UART to string txt[]
          i++;
       }
}

void Wait(){
Delay_ms(1000);
}


void main() {

  UART1_Init(19200);                            // Initialize UART1 module
  Wait(); 

  // Port Expander Library uses SPI1 module
  SPI1_Init();                                  // Initialize SPI module used with PortExpander
  SPI_Lcd_Config(0);                            // Initialize Lcd over SPI interface
  SPI_Lcd_Cmd(_LCD_CLEAR);                      // Clear display
  SPI_Lcd_Cmd(_LCD_CURSOR_OFF);                 // Turn cursor off

  SPI_Lcd_Out(1,1,"Connecting!");
  SPI_Lcd_Out(2,1,"Please, wait...");

  UART1_Write_Text("SET RESET");                // The SET RESET command returns the factory settings of the module    
  UART1_Write(0x0D);                            // CR  
  Wait();
  
  UART1_Write_Text("SET BT PAIR *");            // If command SET BT PAIR * is given, all pairings will be removed      
  UART1_Write(0x0D);                            // CR  
  Wait();
  
  UART1_Write_Text("RESET");                    // Command RESET is used to perform a software reset                  
  UART1_Write(0x0D);                            // CR  
  Wait();
 
  UART1_Write_Text("SET BT AUTH *");            // PIN code will be disabled and no encryption can be used during BT connections      
  UART1_Write(0x0D);                            // CR  
  Wait();
  Wait();
  Wait();  
  Wait();  

  SPI_LCD_Cmd(_LCD_CLEAR);
  SPI_Lcd_Out(1,1,"Connected!");
  DataReady = 0;
// setup interrupts  
  SREG_I_bit  = 1;                              // Enable global interrupt
  RXCIE_bit   = 0;                              // Disable interrupt on UART receive
  Wait();

  SPI_LCD_Cmd(_LCD_CLEAR);                      // Clear display
  SPI_Lcd_Out(1,1,"Receiving...");
  Wait();
  
  while (1) {
    tmp = 0;                                    // Init variables
    i = 0;
    memset(txt, 0, 17);                         // Clear array of chars

    RXCIE_bit   = 1;                            // Interrupts allowed

    while (!DataReady) ;                        // Wait while the data is received

    RXCIE_bit   = 0;                            // Interrupts forbiden
    DataReady = 0;

    SPI_LCD_Cmd(_LCD_CLEAR);                    // Clear display
    SPI_Lcd_Out(1,1,"Received:");
    SPI_Lcd_Cmd(_LCD_SECOND_ROW);
    i = 0;
    while (txt[i] != 0){

       SPI_Lcd_Chr_CP(txt[i]);                  // Displaying the received text on the LCD
       i++;                                     
    }                                           

  }
}