/*
 * Project name:
     Master;
 * Copyright:
     (c) MikroElektronika, 2005-2011.
  * Revision History:
     20110426:
       - initial release (SZ);
 * Description:
     This is a simple project which demonstrates the use of the BlueTooth Stick2 module.
     After establishing the connection Master repeatedly sends two strings ("mikroE" and "BlueTooth Stick2")
     to the Slave. The Slave receives them and displays them at the 2x16 COG LCD.
 * Test configuration:
     MCU:             P32MX460F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61143G.pdf
     Dev.Board:       LV32MX v6
                      http://www.mikroe.com/eng/products/view/462/lv-32mx-v6-development-system/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    BlueTooth Stick2 at PORTF
                      ac:BlueTooth_Stick2_Board
                      http://www.mikroe.com/eng/products/view/680/bluetooth-2-stick/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/categories/view/89/pic32-compilers/
 * NOTES:
  - BlueTooth Stick2: Connect only Vcc, Gnd, Rx and Tx lines. You could use our Wire Jumpers:
    http://www.mikroe.com/eng/products/view/495/wire-jumpers/
  - Turn on both modules at the same time and wait for about one minute until the
    connection between the Master and the Slave establishes.
*/


void Wait(){
Delay_ms(1000);
}

void Wait2(){
char i;
for(i = 0; i < 30; i++) Delay_ms(1000);
}

void main() {
  AD1PCFG = 0xFFFF;                             // Configure AN pins as digital I/O

  UART2_Init(115200);                           // Initialize UART2 module
  Wait(); Wait(); Wait();
  
  UART2_Write_Text("SET RESET");                // The SET RESET command returns the factory settings of the module    
  UART2_Write(0x0D);                            // CR  
  Wait();
  
  UART2_Write_Text("SET BT PAIR *");            // If command SET BT PAIR * is given, all pairings will be removed            
  UART2_Write(0x0D);                            // CR  
  Wait();
  
  UART2_Write_Text("RESET");                    // Command RESET is used to perform a software reset                  
  UART2_Write(0x0D);                            // CR  
  Wait();
 
// The CALL command is used to initiate Bluetooth connections to the remote devices
// Instead of xx:xx:xx:xx:xx:xx enter real MAC address of the BT module you want to call 
  UART2_Write_Text("CALL xx:xx:xx:xx:xx:xx 1 RFCOMM");  
  UART2_Write(0x0D);                            // CR  
  Wait2();

  while (1) {
    UART2_Write_Text("mikroE");                 // Sending Data to Slave module
    UART2_Write(13);                            // CR
    Wait();
    UART2_Write_Text("BlueTooth Stick2");       // Data
    UART2_Write(13);                            // CR
    Wait();
  }
}