/*
 * Project name:
     Slave;
 * Copyright:
     (c) MikroElektronika, 2005-2011.
  * Revision History:
     20110426:
       - initial release (SZ);
 * Description:
     This is a simple project which demonstrates the use of the BlueTooth Stick2 module.
     After establishing the connection Master repeatedly sends two strings ("mikroE" and "BlueTooth Stick2")
     to the Slave. The Slave receives them and displays them at the 2x16 LCD.
 * Test configuration:
     MCU:             PIC24FJ96GA010
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39747e.pdf
     Dev.Board:       LV24-33 v6
                      http://www.mikroe.com/eng/products/view/430/lv-24-33-v6-development-system/
     Oscillator:      HS-PLL, 8.00000 MHz
     Ext. Modules:    BlueTooth Stick2 at PORTF
                      ac:BlueTooth_Stick2_Board
                      http://www.mikroe.com/eng/products/view/680/bluetooth-2-stick/
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
  - BlueTooth Stick2: Connect only Vcc, Gnd, Rx and Tx lines. You could use our Wire Jumpers:
    http://www.mikroe.com/eng/products/view/495/wire-jumpers/
  - Turn on both modules at the same time and wait for about one minute until the
    connection between the Master and the Slave establishes.
  - Turn ON the Lcd Backlight.
*/


// LCD module connections
sbit LCD_RS at LATB2_bit;
sbit LCD_EN at LATB3_bit;
sbit LCD_D4 at LATB4_bit;
sbit LCD_D5 at LATB5_bit;
sbit LCD_D6 at LATB6_bit;
sbit LCD_D7 at LATB7_bit;

sbit LCD_RS_Direction at TRISB2_bit;
sbit LCD_EN_Direction at TRISB3_bit;
sbit LCD_D4_Direction at TRISB4_bit;
sbit LCD_D5_Direction at TRISB5_bit;
sbit LCD_D6_Direction at TRISB6_bit;
sbit LCD_D7_Direction at TRISB7_bit;
// End LCD module connections

char txt[17];
unsigned short i, tmp, DataReady;


// Uart Rx interrupt handler
void interrupt() iv IVT_ADDR_U2RXINTERRUPT {
    tmp = UART2_Read();                         // Get received byte
    U2RXIF_bit = 0;

       if (tmp == 13) {
         txt[i] = 0;                            // Puting 0 at the end of the string
         DataReady = 1;                         // Data is received
       }
        else {
          txt[i] = tmp;                         // Moving the data received from UART to string txt[]
          i++;
     }
}


void Wait(){
Delay_ms(1000);
}


void main() {
// All pins as digital I/Os
  AD1PCFG = 0xFFFF;                             // Configure AN pins as digital I/O

// Initialize UART2 module
  UART2_Init_Advanced(115200,_UART_8BIT_NOPARITY , _UART_ONE_STOPBIT, _UART_HI_SPEED);
  Wait(); 

  LCD_Init();                                   // LCD Init
  LCD_Cmd(_LCD_CLEAR);
  Lcd_Cmd(_LCD_CURSOR_OFF);

  Lcd_Out(1,1,"Connecting!");
  Lcd_Out(2,1,"Please, wait...");

  UART2_Write_Text("SET RESET");                // The SET RESET command returns the factory settings of the module    
  UART2_Write(0x0D);                            // CR  
  Wait();
  
  UART2_Write_Text("SET BT PAIR *");            // If command SET BT PAIR * is given, all pairings will be removed      
  UART2_Write(0x0D);                            // CR  
  Wait();
  
  UART2_Write_Text("RESET");                    // Command RESET is used to perform a software reset                  
  UART2_Write(0x0D);                            // CR  
  Wait();
 
  UART2_Write_Text("SET BT AUTH *");            // PIN code will be disabled and no encryption can be used during BT connections      
  UART2_Write(0x0D);                            // CR  
  Wait();
  Wait();
  Wait();  
  Wait();  

  LCD_Cmd(_LCD_CLEAR);
  Lcd_Out(1,1,"Connected!");
  DataReady = 0;
// setup interrupts
  NSTDIS_bit = 1;                               // No nesting of interrupts
  U2RXIF_bit = 0;                               // Ensure interrupt not pending
  U2RXIE_bit = 0;                               // Disable Rx intterupt
  Wait();

  LCD_Cmd(_LCD_CLEAR);                          // Clear display
  Lcd_Out(1,1,"Receiving...");
  Wait();
  
  while (1) {
    tmp = 0;                                    // Init variables
    i = 0;
    memset(txt, 0, 17);                         // Clear array of chars

    U2RXIE_bit = 1;                             // Interrupts allowed

    while (!DataReady) ;                        // Wait while the data is received

    U2RXIE_bit = 0;                             // Interrupts forbiden
    DataReady = 0;

    LCD_Cmd(_LCD_CLEAR);                        // Clear display
    Lcd_Out(1,1,"Received:");
    Lcd_Cmd(_LCD_SECOND_ROW);
    i = 0;
    while (txt[i] != 0){

       Lcd_Chr_CP(txt[i]);                      // Displaying the received text on the LCD
       i++;                                     
    }                                           

  }
}